@@ -1,5 +1,7 @@
 from pagetools.src.Page import Page
 
+from pathlib import Path
+import glob
 from collections import Counter
 import string
 import json
@@ -19,7 +21,7 @@ from lxml import etree
               help="Only prints n most common entries. Shows all by default.")
 @click.option("-o", "--output", help="File to which results are written.")
 @click.option("-rw", "--remove-whitespace", is_flag=True, default=False)
-@click.option("-of", "--output-format", type=click.Choice(["json", "csv", "txt"]), default="json",
+@click.option("-of", "--output-format", type=click.Choice(["json", "csv", "txt"]), default="csv",
               help="Available result formats.")
 @click.option("-freq", "--frequencies", is_flag=True, default=False, help="Outputs character frequencies.")
 @click.option("--text-output-newline", is_flag=True, default=False,
@@ -28,10 +30,18 @@ from lxml import etree
 def get_codec_cli(files, level, index, most_common, output, remove_whitespace, output_format, frequencies,
                   text_output_newline, verbose):
     codec = Counter()
-
     xpath = build_xpath(level, index)
 
-    with click.progressbar(files) as _files:
+    collected_files = []
+    for file in files:
+        if Path(file).is_file():
+            collected_files.append(file)
+        else:
+            globbed_files = glob.glob(file)
+            for _file in globbed_files:
+                collected_files.append(_file)
+
+    with click.progressbar(collected_files) as _files:
         for file in _files:
             try:
                 page = Page(file)
